package com.ruoyi.project.plant.mapper;

import java.util.List;

import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.plant.domain.TManageactivity;

/**
 * 管理活动抽查Mapper接口
 * 
 * @author ruoyi
 * @date 2020-11-25
 */
public interface TManageactivityMapper 
{
    /**
     * 查询管理活动抽查
     * 
     * @param id 管理活动抽查ID
     * @return 管理活动抽查
     */
    public TManageactivity selectTManageactivityById(Long id);

    /**
     * 查询管理活动抽查列表
     * 
     * @param tManageactivity 管理活动抽查
     * @return 管理活动抽查集合
     */
    @DataScope(deptAlias = "d")
    public List<TManageactivity> selectTManageactivityList(TManageactivity tManageactivity);

    /**
     * 新增管理活动抽查
     * 
     * @param tManageactivity 管理活动抽查
     * @return 结果
     */
    public int insertTManageactivity(TManageactivity tManageactivity);

    /**
     * 修改管理活动抽查
     * 
     * @param tManageactivity 管理活动抽查
     * @return 结果
     */
    public int updateTManageactivity(TManageactivity tManageactivity);

    /**
     * 删除管理活动抽查
     * 
     * @param id 管理活动抽查ID
     * @return 结果
     */
    public int deleteTManageactivityById(Long id);

    /**
     * 批量删除管理活动抽查
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTManageactivityByIds(Long[] ids);
}
